<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>AdvSearch</name>
    <message>
        <source>All clauses</source>
        <translation>Tutti i termini</translation>
    </message>
    <message>
        <source>Any clause</source>
        <translation>Qualsiasi termine</translation>
    </message>
    <message>
        <source>texts</source>
        <translation>testi</translation>
    </message>
    <message>
        <source>spreadsheets</source>
        <translation>fogli di calcolo</translation>
    </message>
    <message>
        <source>presentations</source>
        <translation>presentazioni</translation>
    </message>
    <message>
        <source>media</source>
        <translation>multimediali</translation>
    </message>
    <message>
        <source>messages</source>
        <translation>messaggi</translation>
    </message>
    <message>
        <source>other</source>
        <translation>altri</translation>
    </message>
    <message>
        <source>Bad multiplier suffix in size filter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdvSearchBase</name>
    <message>
        <source>Advanced search</source>
        <translation>Ricerca avanzata</translation>
    </message>
    <message>
        <source>Restrict file types</source>
        <translation>Limita i tipi di file</translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation>Salva come default</translation>
    </message>
    <message>
        <source>Searched file types</source>
        <translation>Ricerca tipo file</translation>
    </message>
    <message>
        <source>All ----&gt;</source>
        <translation>Tutti ----&gt;</translation>
    </message>
    <message>
        <source>Sel -----&gt;</source>
        <translation>Sel -----&gt;</translation>
    </message>
    <message>
        <source>&lt;----- Sel</source>
        <translation>&lt;----- Sel</translation>
    </message>
    <message>
        <source>&lt;----- All</source>
        <translation>&lt;----- Tutti</translation>
    </message>
    <message>
        <source>Ignored file types</source>
        <translation>Ignora i file di questo tipo</translation>
    </message>
    <message>
        <source>Enter top directory for search</source>
        <translation>Scrivi la directory base per la ricerca</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Esplora</translation>
    </message>
    <message>
        <source>Restrict results to files in subtree:</source>
        <translation>Limita i risultati alla sotto-directory: </translation>
    </message>
    <message>
        <source>Start Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Search for &lt;br&gt;documents&lt;br&gt;satisfying:</source>
        <translation>Cerca i documenti&lt;br&gt;che contengono:</translation>
    </message>
    <message>
        <source>Delete clause</source>
        <translation>Elimina condizione</translation>
    </message>
    <message>
        <source>Add clause</source>
        <translation>Aggiungi condizione</translation>
    </message>
    <message>
        <source>Check this to enable filtering on file types</source>
        <translation>Contrassegna per abilitare la ricerca sul tipo di file</translation>
    </message>
    <message>
        <source>By categories</source>
        <translation>Per categorie</translation>
    </message>
    <message>
        <source>Check this to use file categories instead of raw mime types</source>
        <translation>Contrassegna per usare le categorie al posto dei tipi mime</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>All non empty fields on the right will be combined with AND (&quot;All clauses&quot; choice) or OR (&quot;Any clause&quot; choice) conjunctions. &lt;br&gt;&quot;Any&quot; &quot;All&quot; and &quot;None&quot; field types can accept a mix of simple words, and phrases enclosed in double quotes.&lt;br&gt;Fields with no data are ignored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minimum size. You can use k/K,m/M,g/G as multipliers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Min. Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum size. You can use k/K,m/M,g/G as multipliers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max. Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this to enable filtering on dates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter dates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this to enable filtering on sizes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter sizes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CronToolW</name>
    <message>
        <source>Cron Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Recoll&lt;/span&gt; batch indexing schedule (cron) &lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Each field can contain a wildcard (*), a single numeric value, comma-separated lists (1,3,5) and ranges (1-7). More generally, the fields will be used &lt;span style=&quot; font-style:italic;&quot;&gt;as is&lt;/span&gt; inside the crontab file, and the full crontab syntax can be used, see crontab(5).&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;For example, entering &lt;span style=&quot; font-family:&apos;Courier New,courier&apos;;&quot;&gt;*&lt;/span&gt; in &lt;span style=&quot; font-style:italic;&quot;&gt;Days, &lt;/span&gt;&lt;span style=&quot; font-family:&apos;Courier New,courier&apos;;&quot;&gt;12,19&lt;/span&gt; in &lt;span style=&quot; font-style:italic;&quot;&gt;Hours&lt;/span&gt; and &lt;span style=&quot; font-family:&apos;Courier New,courier&apos;;&quot;&gt;15&lt;/span&gt; in &lt;span style=&quot; font-style:italic;&quot;&gt;Minutes&lt;/span&gt; would start recollindex every day at 12:15 AM and 7:15 PM&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;A schedule with very frequent activations is probably less efficient than real time indexing.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Days of week (* or 0-7, 0 or 7 is Sunday)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hours (* or 0-23)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minutes (0-59)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Click &lt;span style=&quot; font-style:italic;&quot;&gt;Disable&lt;/span&gt; to stop automatic batch indexing, &lt;span style=&quot; font-style:italic;&quot;&gt;Enable&lt;/span&gt; to activate it, &lt;span style=&quot; font-style:italic;&quot;&gt;Cancel&lt;/span&gt; to change nothing.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It seems that manually edited entries exist for recollindex, cannot edit crontab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error installing cron entry. Bad syntax in fields ?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FirstIdxDialog</name>
    <message>
        <source>First indexing setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;It appears that the index for this configuration does not exist.&lt;/span&gt;&lt;br /&gt;&lt;br /&gt;If you just want to index your home directory with a set of reasonable defaults, press the &lt;span style=&quot; font-style:italic;&quot;&gt;Start indexing now&lt;/span&gt; button. You will be able to adjust the details later. &lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;If you want more control, use the following links to adjust the indexing configuration and schedule.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;These tools can be accessed later from the &lt;span style=&quot; font-style:italic;&quot;&gt;Preferences&lt;/span&gt; menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indexing configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will let you adjust the directories you want to index, and other parameters like excluded file paths or names, default character sets, etc.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indexing schedule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will let you chose between batch and real-time indexing, and set up an automatic  schedule for batch indexing (using cron).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start indexing now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IdxSchedW</name>
    <message>
        <source>Index scheduling setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Recoll&lt;/span&gt; indexing can run permanently, indexing files as they change, or run at discrete intervals. &lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Reading the manual may help you to decide between these approaches (press F1). &lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This tool can help you set up a schedule to automate batch indexing runs, or start real time indexing when you log in (or both, which rarely makes sense). &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cron scheduling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The tool will let you decide at what time indexing should run and will install a crontab entry.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Real time indexing start up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decide if real time indexing will be started when you log in (only for the default index).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GroupBox</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>No db directory in configuration</source>
        <translation>Nessuna directory per il DB di base nella configurazione</translation>
    </message>
    <message>
        <source>Could not open database in </source>
        <translation type="obsolete">Impossibile aprire il database in </translation>
    </message>
    <message>
        <source>.
Click Cancel if you want to edit the configuration file before indexing starts, or Ok to let it proceed.</source>
        <translation type="obsolete">Clicca &apos;Annulla&apos; se vuoi editare il file di configurazione prima di iniziare l&apos;indicizzazione, oppure &apos;OK&apos; se vuoi procedere.</translation>
    </message>
    <message>
        <source>Configuration problem (dynconf</source>
        <translation type="obsolete">Problema di configurazione (dynconf</translation>
    </message>
    <message>
        <source>&quot;history&quot; file is damaged or un(read)writeable, please check or remove it: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Preview</name>
    <message>
        <source>&amp;Search for:</source>
        <translation>&amp;Cerca:</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Successivo</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>&amp;Precedente</translation>
    </message>
    <message>
        <source>Match &amp;Case</source>
        <translation>Rispetta &amp;Maiuscole/minuscole</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>Creating preview text</source>
        <translation>Creazione del testo per l&apos;anteprima</translation>
    </message>
    <message>
        <source>Loading preview text into editor</source>
        <translation>Caricamento anteprima del testo nell&apos;editor</translation>
    </message>
    <message>
        <source>Cannot create temporary directory</source>
        <translation type="obsolete">Impossibile creare directory temporanea</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Close Tab</source>
        <translation>Chiudi Tab</translation>
    </message>
    <message>
        <source>Missing helper program: </source>
        <translation>Manca il programma di filtro esterno: </translation>
    </message>
    <message>
        <source>Can&apos;t turn doc into internal representation for </source>
        <translation>Impossibile tradurre il documento per la rappresentazione interna </translation>
    </message>
    <message>
        <source>Cannot create temporary directory: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error while loading file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreviewTextEdit</name>
    <message>
        <source>Show fields</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show main text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print Current Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save document to file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fold lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preserve indentation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Global parameters</source>
        <translation>Parametri globali</translation>
    </message>
    <message>
        <source>Local parameters</source>
        <translation>Parametri locali</translation>
    </message>
    <message>
        <source>&lt;b&gt;Customised subtrees</source>
        <translation>&lt;b&gt;Ramificazioni personalizzate</translation>
    </message>
    <message>
        <source>The list of subdirectories in the indexed hierarchy &lt;br&gt;where some parameters need to be redefined. Default: empty.</source>
        <translation>Lista delle sottocartelle nella gerarchia indicizzata&lt;br&gt;ove alcuni parametri devono essere ridefiniti. Predefinita: vuota.</translation>
    </message>
    <message>
        <source>&lt;i&gt;The parameters that follow are set either at the top level, if nothing&lt;br&gt;or an empty line is selected in the listbox above, or for the selected subdirectory.&lt;br&gt;You can add or remove directories by clicking the +/- buttons.</source>
        <translation>&lt;i&gt;I parametri che seguono sono postii al livello superiore, se niente &lt;br&gt; o una linea vuota è selezionata nella casella sovrastante, oppure al livello della cartella selezionata.&lt;br&gt; Puoi aggiungere/rimuovere cartelle cliccando i bottoni +/-.</translation>
    </message>
    <message>
        <source>Skipped names</source>
        <translation>Nomi saltati</translation>
    </message>
    <message>
        <source>These are patterns for file or directory  names which should not be indexed.</source>
        <translation>Questi sono modelli per i nomi delle cartelle e/o dei files che non devono vebire indicizzati.</translation>
    </message>
    <message>
        <source>Default character set</source>
        <translation>Set di caratteri di default</translation>
    </message>
    <message>
        <source>This is the character set used for reading files which do not identify the character set internally, for example pure text files.&lt;br&gt;The default value is empty, and the value from the NLS environnement is used.</source>
        <translation>Questa è la codifica caratteri usata per leggere i file che non contengono indicazioni interne sulla codifica usata, ad esempio file di testo semplice.&lt;br&gt;Il valore predefinito è vuoto, in modo che venga usata l&apos;impostazione locale del sistema.</translation>
    </message>
    <message>
        <source>Follow symbolic links</source>
        <translation>Segue il link simbolico</translation>
    </message>
    <message>
        <source>Follow symbolic links while indexing. The default is no, to avoid duplicate indexing</source>
        <translation>Segue il link simbolico durante l&apos;indicizzazione. Di default è no, per evitare la duplicazione dell&apos;indice</translation>
    </message>
    <message>
        <source>Index all file names</source>
        <translation>Indicizza tutti i nomi dei files</translation>
    </message>
    <message>
        <source>Index the names of files for which the contents cannot be identified or processed (no or unsupported mime type). Default true</source>
        <translation>Indicizza il nome di quei files il cui contenuto non può essere identificato o processato (tipo mime non supportato). Di default è impostato a vero</translation>
    </message>
    <message>
        <source>Beagle web history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RTIToolW</name>
    <message>
        <source>Real time indexing automatic start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Recoll&lt;/span&gt; indexing can be set up to run as a daemon, updating the index as files change, in real time. You gain an always up to date index, but system resources are used permanently.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start indexing daemon with my desktop session.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Also start indexing daemon right now.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replacing: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replacing file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t create: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Attenzione</translation>
    </message>
    <message>
        <source>Could not execute recollindex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Removing autostart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autostart file deleted. Kill current process too ?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RclMain</name>
    <message>
        <source>About Recoll</source>
        <translation>Informazioni su Recoll</translation>
    </message>
    <message>
        <source>Executing: [</source>
        <translation>Esecuzione di: [</translation>
    </message>
    <message>
        <source>Cannot retrieve document info from database</source>
        <translation>Impossibile caricare informazioni del documento dal database</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <source>Can&apos;t create preview window</source>
        <translation>Non posso creare la finestra di anteprima</translation>
    </message>
    <message>
        <source>Query results</source>
        <translation>Risultati della ricerca</translation>
    </message>
    <message>
        <source>Document history</source>
        <translation>Cronologia dei documenti</translation>
    </message>
    <message>
        <source>History data</source>
        <translation>Cronologia dei dati</translation>
    </message>
    <message>
        <source>Indexing in progress: </source>
        <translation>Indicizzazione in corso:  </translation>
    </message>
    <message>
        <source>Files</source>
        <translation type="obsolete">Files</translation>
    </message>
    <message>
        <source>Purge</source>
        <translation>Pulisco</translation>
    </message>
    <message>
        <source>Stemdb</source>
        <translation>Database espansioni</translation>
    </message>
    <message>
        <source>Closing</source>
        <translation>Chiusura</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
    <message>
        <source>This search is not active any more</source>
        <translation>Questa ricerca non e&apos; piu&apos; attiva</translation>
    </message>
    <message>
        <source>Can&apos;t start query: </source>
        <translation type="obsolete">Non posso iniziare la ricerca: </translation>
    </message>
    <message>
        <source>Bad viewer command line for %1: [%2]
Please check the mimeconf file</source>
        <translation>Errata linea di comando per %1: [%2]
Verifica il file mimeconf</translation>
    </message>
    <message>
        <source>Cannot extract document or create temporary file</source>
        <translation>Non posso estrarre il documento o creare il file temporaneo</translation>
    </message>
    <message>
        <source>(no stemming)</source>
        <translation>(nessuna espansione)</translation>
    </message>
    <message>
        <source>(all languages)</source>
        <translation>(tutte le lingue)</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>errore nel recupero delle lingue per l&apos;espansione</translation>
    </message>
    <message>
        <source>Update &amp;Index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop &amp;Indexing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>media</source>
        <translation>multimediali</translation>
    </message>
    <message>
        <source>message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>other</source>
        <translation>altri</translation>
    </message>
    <message>
        <source>presentation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sorted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>filtered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>External applications/commands needed and not found for indexing your file types:

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No helpers found missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing helper programs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document category filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No external viewer configured for mime type [</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The viewer specified in mimeview for %1: %2 is not found.
Do you want to start the  preferences dialog ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t access file: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t uncompress file: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Result count (est.)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Query details</source>
        <translation type="unfinished">Dettagli ricerca</translation>
    </message>
    <message>
        <source>Could not open external index. Db not open. Check external indexes list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No results found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indexing failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The current indexing process was not started from this interface. Click Ok to kill it anyway, or Cancel to leave it alone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Erasing index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset the index and start from scratch ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Query in progress.&lt;br&gt;Due to limitations of the indexing library,&lt;br&gt;cancelling will exit the program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Index not open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Index query error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Content has been indexed for these mime types:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Index not up to date for this file. Refusing to risk showing the wrong entry. Click Ok to update the index for this file, then re-run the query when indexing is done. Else, Cancel.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t update index: indexer running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indexed MIME Types</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RclMainBase</name>
    <message>
        <source>Previous page</source>
        <translation>Pagina precedente</translation>
    </message>
    <message>
        <source>Next page</source>
        <translation>Pagina seguente</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Strumenti</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Preferenze</translation>
    </message>
    <message>
        <source>Search tools</source>
        <translation>Strumenti di ricerca</translation>
    </message>
    <message>
        <source>Result list</source>
        <translation>Lista risultati</translation>
    </message>
    <message>
        <source>&amp;About Recoll</source>
        <translation>&amp;Informazioni su Recoll</translation>
    </message>
    <message>
        <source>Document &amp;History</source>
        <translation>C&amp;ronologia documenti</translation>
    </message>
    <message>
        <source>Document  History</source>
        <translation>Visualizza la cronologia dei documenti</translation>
    </message>
    <message>
        <source>&amp;Advanced Search</source>
        <translation>Ricerca &amp;Avanzata</translation>
    </message>
    <message>
        <source>Advanced/complex  Search</source>
        <translation>Mostra la finestra di Ricerca avanzata</translation>
    </message>
    <message>
        <source>&amp;Sort parameters</source>
        <translation>&amp;Parametri ordinamento</translation>
    </message>
    <message>
        <source>Sort parameters</source>
        <translation>Configurazione dei parametri di ordinamento</translation>
    </message>
    <message>
        <source>Next page of results</source>
        <translation>Pagina seguente</translation>
    </message>
    <message>
        <source>Previous page of results</source>
        <translation>Pagina precedente</translation>
    </message>
    <message>
        <source>&amp;Query configuration</source>
        <translation>&amp;Configurazione ricerca</translation>
    </message>
    <message>
        <source>&amp;User manual</source>
        <translation>&amp;Manuale utente</translation>
    </message>
    <message>
        <source>Recoll</source>
        <translation>Recoll</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Update &amp;index</source>
        <translation>Aggiorna &amp;indice</translation>
    </message>
    <message>
        <source>Term &amp;explorer</source>
        <translation>&amp;Esplora l&apos;indice</translation>
    </message>
    <message>
        <source>Term explorer tool</source>
        <translation>Strumento di esplorazione indice</translation>
    </message>
    <message>
        <source>External index dialog</source>
        <translation>Configurazione indici esterni</translation>
    </message>
    <message>
        <source>&amp;Erase document history</source>
        <translation>&amp;Cancella la cronologia dei documenti</translation>
    </message>
    <message>
        <source>First page</source>
        <translation>Prima pagina</translation>
    </message>
    <message>
        <source>Go to first page of results</source>
        <translation>Vai alla prima pagina dei risultati</translation>
    </message>
    <message>
        <source>&amp;Indexing configuration</source>
        <translation>Conf&amp;igurazione indicizzazione</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Show missing helpers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F11</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Full Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Erase search history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sortByDateAsc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort by dates from oldest to newest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sortByDateDesc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort by dates from newest to oldest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Query Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show results as table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Rebuild index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Show indexed types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shift+PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Indexing schedule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;xternal index dialog</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecollModel</name>
    <message>
        <source>File name</source>
        <translation type="unfinished">Nome file</translation>
    </message>
    <message>
        <source>Mime type</source>
        <translation type="obsolete">Tipo MIME</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Data</translation>
    </message>
    <message>
        <source>Abstract</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Original character set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Relevancy rating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mtime</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date and time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ipath</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MIME type</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResList</name>
    <message>
        <source>Result list</source>
        <translation>Lista dei risultati</translation>
    </message>
    <message>
        <source>Unavailable document</source>
        <translation>Documento inaccessible</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Precedente</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Successivo</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Nessun risultato&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Anteprima</translation>
    </message>
    <message>
        <source>Copy &amp;URL</source>
        <translation>Copia l&apos;&amp;Url</translation>
    </message>
    <message>
        <source>Find &amp;similar documents</source>
        <translation>Trova documenti &amp;simili</translation>
    </message>
    <message>
        <source>Query details</source>
        <translation type="obsolete">Dettagli ricerca</translation>
    </message>
    <message>
        <source>(show query)</source>
        <translation> (mostra dettagli di ricerca)</translation>
    </message>
    <message>
        <source>Copy &amp;File Name</source>
        <translation>Copia il nome del &amp;File</translation>
    </message>
    <message>
        <source>Document history</source>
        <translation>Cronologia dei documenti</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;i&gt;Alternate spellings (accents suppressed): &lt;/i&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Write to File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preview P&amp;arent document/folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open Parent document/folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Risultati</translation>
    </message>
    <message>
        <source>out of at least</source>
        <translation>totale di almeno</translation>
    </message>
    <message>
        <source>for</source>
        <translation>per</translation>
    </message>
</context>
<context>
    <name>ResTable</name>
    <message>
        <source>&amp;Reset sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete column</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save table to CSV file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t open/create file: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="unfinished">&amp;Anteprima</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy &amp;File Name</source>
        <translation type="unfinished">Copia il nome del &amp;File</translation>
    </message>
    <message>
        <source>Copy &amp;URL</source>
        <translation type="unfinished">Copia l&apos;&amp;Url</translation>
    </message>
    <message>
        <source>&amp;Write to File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find &amp;similar documents</source>
        <translation type="unfinished">Trova documenti &amp;simili</translation>
    </message>
    <message>
        <source>Preview P&amp;arent document/folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open Parent document/folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save as CSV</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add &quot;%1&quot; column</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResTableDetailArea</name>
    <message>
        <source>&amp;Preview</source>
        <translation type="unfinished">&amp;Anteprima</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy &amp;File Name</source>
        <translation type="unfinished">Copia il nome del &amp;File</translation>
    </message>
    <message>
        <source>Copy &amp;URL</source>
        <translation type="unfinished">Copia l&apos;&amp;Url</translation>
    </message>
    <message>
        <source>&amp;Write to File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find &amp;similar documents</source>
        <translation type="unfinished">Trova documenti &amp;simili</translation>
    </message>
    <message>
        <source>Preview P&amp;arent document/folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open Parent document/folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SSearch</name>
    <message>
        <source>Any term</source>
        <translation>Qualsiasi</translation>
    </message>
    <message>
        <source>All terms</source>
        <translation>Tutti</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Nome file</translation>
    </message>
    <message>
        <source>Completions</source>
        <translation>Espansione</translation>
    </message>
    <message>
        <source>Select an item:</source>
        <translation>Seleziona una voce: </translation>
    </message>
    <message>
        <source>Too many completions</source>
        <translation>Troppe possibilita&apos; di espansione</translation>
    </message>
    <message>
        <source>Query language</source>
        <translation>Linguaggio di interrogazione</translation>
    </message>
    <message>
        <source>Bad query string</source>
        <translation>Stringa di ricerca malformata</translation>
    </message>
    <message>
        <source>Out of memory</source>
        <translation>Memoria esaurita</translation>
    </message>
    <message>
        <source>Enter query language expression. Cheat sheet:&lt;br&gt;
&lt;i&gt;term1 term2&lt;/i&gt; : &apos;term1&apos; and &apos;term2&apos; in any field.&lt;br&gt;
&lt;i&gt;field:term1&lt;/i&gt; : &apos;term1&apos; in field &apos;field&apos;.&lt;br&gt;
 Standard field names/synonyms:&lt;br&gt;
  title/subject/caption, author/from, recipient/to, filename, ext.&lt;br&gt;
 Pseudo-fields: dir, mime/format, type/rclcat, date.&lt;br&gt;
 Two date interval exemples: 2009-03-01/2009-05-20  2009-03-01/P2M.&lt;br&gt;
&lt;i&gt;term1 term2 OR term3&lt;/i&gt; : term1 AND (term2 OR term3).&lt;br&gt;
  No actual parentheses allowed.&lt;br&gt;
&lt;i&gt;&quot;term1 term2&quot;&lt;/i&gt; : phrase (must occur exactly). Possible modifiers:&lt;br&gt;
&lt;i&gt;&quot;term1 term2&quot;p&lt;/i&gt; : unordered proximity search with default distance.&lt;br&gt;
Use &lt;b&gt;Show Query&lt;/b&gt; link when in doubt about result and see manual (&amp;lt;F1&gt;) for more detail.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter file name wildcard expression.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter search terms here. Type ESC SPC for completions of current term.</source>
        <translation>Inserisci qui i termini di ricerca. Premi ESC Spazio per il completamento automatico dei termini.</translation>
    </message>
</context>
<context>
    <name>SSearchBase</name>
    <message>
        <source>SSearchBase</source>
        <translation>SSearchBase</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Erase search entry</source>
        <translation>Cancella voce di ricerca</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Start query</source>
        <translation>Inizia ricerca</translation>
    </message>
    <message>
        <source>Enter search terms here. Type ESC SPC for completions of current term.</source>
        <translation>Inserisci qui i termini di ricerca. Premi ESC Spazio per il completamento automatico dei termini.</translation>
    </message>
    <message>
        <source>Choose search type.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchClauseW</name>
    <message>
        <source>SearchClauseW</source>
        <translation type="obsolete">SearchClauseW</translation>
    </message>
    <message>
        <source>Any of these</source>
        <translation type="obsolete">Qualsiasi parola</translation>
    </message>
    <message>
        <source>All of these</source>
        <translation type="obsolete">Tutte le parole</translation>
    </message>
    <message>
        <source>None of these</source>
        <translation type="obsolete">Nessuna di queste</translation>
    </message>
    <message>
        <source>This phrase</source>
        <translation type="obsolete">Questa frase</translation>
    </message>
    <message>
        <source>Terms in proximity</source>
        <translation type="obsolete">Parole in prossimita&apos;</translation>
    </message>
    <message>
        <source>File name matching</source>
        <translation type="obsolete">Nome del file</translation>
    </message>
    <message>
        <source>Select the type of query that will be performed with the words</source>
        <translation>Seleziona il tipo di ricerca da effettuare con i termini indicati</translation>
    </message>
    <message>
        <source>Number of additional words that may be interspersed with the chosen ones</source>
        <translation>Numero di parole che possono frapporsi tra i termini di ricerca indicati</translation>
    </message>
    <message>
        <source>No field</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Any</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Phrase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proximity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File name</source>
        <translation type="unfinished">Nome file</translation>
    </message>
</context>
<context>
    <name>SortForm</name>
    <message>
        <source>Date</source>
        <translation type="obsolete">Data</translation>
    </message>
    <message>
        <source>Mime type</source>
        <translation type="obsolete">Tipo MIME</translation>
    </message>
</context>
<context>
    <name>SortFormBase</name>
    <message>
        <source>Sort Criteria</source>
        <translation type="obsolete">Criterio di ordinamento</translation>
    </message>
    <message>
        <source>Sort the</source>
        <translation type="obsolete">Ordina i</translation>
    </message>
    <message>
        <source>most relevant results by:</source>
        <translation type="obsolete">risultati piu&apos; rilevanti per: </translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="obsolete">Discendente</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">Chiudi</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="obsolete">Applica</translation>
    </message>
</context>
<context>
    <name>SpellBase</name>
    <message>
        <source>Term Explorer</source>
        <translation>Esplorazione dei termini</translation>
    </message>
    <message>
        <source>&amp;Expand </source>
        <translation>&amp;Espandi </translation>
    </message>
    <message>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <source>Term</source>
        <translation type="obsolete">Termine</translation>
    </message>
    <message>
        <source>No db info.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpellW</name>
    <message>
        <source>Wildcards</source>
        <translation>Caratteri jolly</translation>
    </message>
    <message>
        <source>Regexp</source>
        <translation>Espressione regolare</translation>
    </message>
    <message>
        <source>Spelling/Phonetic</source>
        <translation>Ortografia/Fonetica</translation>
    </message>
    <message>
        <source>Aspell init failed. Aspell not installed?</source>
        <translation>Errore di inizializzazione aspell. Aspell e&apos; installato?</translation>
    </message>
    <message>
        <source>Aspell expansion error. </source>
        <translation>Errore di espansione di Aspell. </translation>
    </message>
    <message>
        <source>Stem expansion</source>
        <translation>Espansione grammaticale</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>Impossibile formare la lista di espansione per la lingua</translation>
    </message>
    <message>
        <source>No expansion found</source>
        <translation>Nessun epansione trovata</translation>
    </message>
    <message>
        <source>Term</source>
        <translation>Termine</translation>
    </message>
    <message>
        <source>Doc. / Tot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Index: %1 documents, average length %2 terms</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UIPrefsDialog</name>
    <message>
        <source>The selected directory does not appear to be a Xapian index</source>
        <translation>La directory selezionata non sembra essera un indice Xapian</translation>
    </message>
    <message>
        <source>This is the main/local index!</source>
        <translation>Questo e&apos; l&apos;indice principale!</translation>
    </message>
    <message>
        <source>The selected directory is already in the index list</source>
        <translation>La directory selezionata e&apos; gia&apos; nella lista</translation>
    </message>
    <message>
        <source>Select xapian index directory (ie: /home/buddy/.recoll/xapiandb)</source>
        <translation>Seleziona la directory indice Xapian 
(es.: /home/ciccio/.recoll/xapiandb)</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>Impossibile formare la lista delle lingue per l&apos;espansione grammaticale</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UIPrefsDialogBase</name>
    <message>
        <source>User interface</source>
        <translation type="obsolete">Interfaccia utente</translation>
    </message>
    <message>
        <source>Number of entries in a result page</source>
        <translation type="obsolete">Numero di risultati per pagina</translation>
    </message>
    <message>
        <source>Result list font</source>
        <translation type="obsolete">Fonts per la lista dei risultati</translation>
    </message>
    <message>
        <source>Helvetica-10</source>
        <translation type="obsolete">Helvetica-10</translation>
    </message>
    <message>
        <source>Opens a dialog to select the result list font</source>
        <translation type="obsolete">Apre una finestra di dialogo per selezionare i fonts della lista dei risultati</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="obsolete">Ripristina</translation>
    </message>
    <message>
        <source>Resets the result list font to the system default</source>
        <translation type="obsolete">Ripristina i font della lista dei risultati</translation>
    </message>
    <message>
        <source>Auto-start simple search on whitespace entry.</source>
        <translation type="obsolete">Inizia automaticamente una ricerca semplice digitando uno spazio.</translation>
    </message>
    <message>
        <source>Start with advanced search dialog open.</source>
        <translation type="obsolete">Inizia aprendo la finestra di ricerca avanzata.</translation>
    </message>
    <message>
        <source>Start with sort dialog open.</source>
        <translation type="obsolete">Inizia con la finestra di ordinamento aperta.</translation>
    </message>
    <message>
        <source>Search parameters</source>
        <translation type="obsolete">Parametri per la ricerca</translation>
    </message>
    <message>
        <source>Stemming language</source>
        <translation type="obsolete">Linguaggio per l&apos;espansione</translation>
    </message>
    <message>
        <source>Dynamically build abstracts</source>
        <translation type="obsolete">Costruisci dinamicamente i riassunti</translation>
    </message>
    <message>
        <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
May be slow for big documents.</source>
        <translation type="obsolete">Devo cercare di costruire i riassunti per le voci nell&apos;elenco dei risultati usando il contesto dei termini di ricerca?
Puo&apos; essere lento per grossi documenti..</translation>
    </message>
    <message>
        <source>Replace abstracts from documents</source>
        <translation type="obsolete">Sostituisci i riassunti dei documenti</translation>
    </message>
    <message>
        <source>Do we synthetize an abstract even if the document seemed to have one?</source>
        <translation type="obsolete">Devo sintetizzare un riassunto anche se il documento sembra ne abbia uno?</translation>
    </message>
    <message>
        <source>Synthetic abstract size (characters)</source>
        <translation type="obsolete">Numero caratteri per il riassunto</translation>
    </message>
    <message>
        <source>Synthetic abstract context words</source>
        <translation type="obsolete">Numero di parole di contesto per il riassunto</translation>
    </message>
    <message>
        <source>External Indexes</source>
        <translation type="obsolete">Indici esterni</translation>
    </message>
    <message>
        <source>Add index</source>
        <translation type="obsolete">Aggiungi indice</translation>
    </message>
    <message>
        <source>Select the xapiandb directory for the index you want to add, then click Add Index</source>
        <translation type="obsolete">Seleziona nella directory Xapiandb l&apos;indice che vuoi aggiungere e clicca su &apos;Aggiungi indice&apos;</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="obsolete">Esplora</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Apply changes</source>
        <translation type="obsolete">Applica modifiche</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Annulla</translation>
    </message>
    <message>
        <source>Discard changes</source>
        <translation type="obsolete">Annulla modifiche</translation>
    </message>
    <message>
        <source>Result paragraph&lt;br&gt;format string</source>
        <translation type="obsolete">Stringa di formattazione&lt;br&gt;dei risultati</translation>
    </message>
    <message>
        <source>Automatically add phrase to simple searches</source>
        <translation type="obsolete">Aggiungi automaticamente frase alle ricerche semplici</translation>
    </message>
    <message>
        <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)]. 
This should give higher precedence to the results where the search terms appear exactly as entered.</source>
        <translation type="obsolete">Una ricerca per [vino rosso] (2 parole) sara&apos; completata come [vino O rosso O (vino FRASE 2 rosso)]. 
Questo dovrebbe dare la precedenza ai risultati che contengono i termini esattamente come sono stati scritti.</translation>
    </message>
    <message>
        <source>User preferences</source>
        <translation type="obsolete">Preferenze utente</translation>
    </message>
    <message>
        <source>Use desktop preferences to choose document editor.</source>
        <translation type="obsolete">Usa le preferenze del desktop per scegliere l&apos;editor dei documenti.</translation>
    </message>
    <message>
        <source>External indexes</source>
        <translation type="obsolete">Indici esterni</translation>
    </message>
    <message>
        <source>Toggle selected</source>
        <translation type="obsolete">Commuta selezionati</translation>
    </message>
    <message>
        <source>Activate All</source>
        <translation type="obsolete">Seleziona tutti</translation>
    </message>
    <message>
        <source>Deactivate All</source>
        <translation type="obsolete">Deseleziona tutti</translation>
    </message>
    <message>
        <source>Remove selected</source>
        <translation type="obsolete">Rimuovi selezionati</translation>
    </message>
    <message>
        <source>Remove from list. This has no effect on the disk index.</source>
        <translation type="obsolete">Rimuovi dalla lista. Non ha effetto sull&apos;indice del disco.</translation>
    </message>
    <message>
        <source>Defines the format for each result list paragraph. Use qt html format and printf-like replacements:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %I Icon image name&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</source>
        <translation type="obsolete">Definisce il formato per ogni paragrafo dell&apos;elenco dei risultati. Usare il formato qt html e le sostituzioni tipo printf:&lt;br&gt;%A Riassunto&lt;br&gt; %D Data&lt;br&gt; %I Icona&lt;br&gt; %K Parole chiave (se esistono)&lt;br&gt; %L Link per anteprima e modifica&lt;br&gt; %M Tipo MIME&lt;br&gt; %N Numero del risultato&lt;br&gt; %R Percentuale di rilevanza&lt;br&gt; %S Informazioni sulla dimensione&lt;br&gt; %T Titolo&lt;br&gt; %U Url&lt;br&gt;</translation>
    </message>
    <message>
        <source>Remember sort activation state.</source>
        <translation type="obsolete">Ricorda lo stato dell&apos;impostazione di ordinamento.</translation>
    </message>
    <message>
        <source>Maximum text size highlighted for preview (megabytes)</source>
        <translation type="obsolete">Dimensione massima del testo da evidenziare nell&apos;anteprima (megabytes)</translation>
    </message>
    <message>
        <source>Texts over this size will not be highlighted in preview (too slow).</source>
        <translation type="obsolete">Testi di lunghezza superiore a questa non vengono evidenziati nella preview (troppo lento).</translation>
    </message>
</context>
<context>
    <name>ViewAction</name>
    <message>
        <source>Changing actions with different current values</source>
        <translation>Modifica di azioni con valori differenti da quelli attuali</translation>
    </message>
    <message>
        <source>Mime type</source>
        <translation type="obsolete">Tipo MIME</translation>
    </message>
    <message>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MIME type</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewActionBase</name>
    <message>
        <source>File type</source>
        <translation type="obsolete">Tipo di file</translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="obsolete">Azione</translation>
    </message>
    <message>
        <source>Select one or several file types, then click Change Action to modify the program used to open them</source>
        <translation>Seleziona uno o piu&apos; tipi di file e poi clicca su &apos;Cambia Azione&apos; per modificare il programma usato per aprirli</translation>
    </message>
    <message>
        <source>Change Action</source>
        <translation>Cambia Azione</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Native Viewers</source>
        <translation>Applicazione di visualizzazione</translation>
    </message>
    <message>
        <source>Select one or several mime types then click &quot;Change Action&quot;&lt;br&gt;You can also close this dialog and check &quot;Use desktop preferences&quot;&lt;br&gt;in the main panel to ignore this list and use your desktop defaults.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>confgui::ConfBeaglePanelW</name>
    <message>
        <source>Steal Beagle indexing queue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Beagle MUST NOT be running. Enables processing the beagle queue to index Firefox web history.&lt;br&gt;(you should also install the Firefox Beagle plugin)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Entries will be recycled once the size is reached</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Web page store directory name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name for a directory where to store the copies of visited web pages.&lt;br&gt;A non-absolute path is taken relative to the configuration directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max. size for the web store (MB)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>confgui::ConfIndexW</name>
    <message>
        <source>Can&apos;t write configuration file</source>
        <translation>Impossibile scrivere il file di configurazione</translation>
    </message>
</context>
<context>
    <name>confgui::ConfParamFNW</name>
    <message>
        <source>Browse</source>
        <translation type="obsolete">Esplora</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>confgui::ConfParamSLW</name>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
</context>
<context>
    <name>confgui::ConfSubPanelW</name>
    <message>
        <source>Global</source>
        <translation>Globale</translation>
    </message>
    <message>
        <source>Max. compressed file size (KB)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This value sets a threshold beyond which compressedfiles will not be processed. Set to -1 for no limit, to 0 for no decompression ever.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max. text file size (MB)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This value sets a threshold beyond which text files will not be processed. Set to -1 for no limit. 
This is for excluding monster log files from the index.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text file page size (KB)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this value is set (not equal to -1), text files will be split in chunks of this size for indexing.
This will help searching very big text  files (ie: log files).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max. filter exec. time (S)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>External filters working longer than this will be aborted. This is for the rare case (ie: postscript) where a document could cause a filter to loopSet to -1 for no limit.
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>confgui::ConfTopPanelW</name>
    <message>
        <source>Top directories</source>
        <translation>Cartella superiore</translation>
    </message>
    <message>
        <source>The list of directories where recursive indexing starts. Default: your home.</source>
        <translation>Lista delle cartelle in cui inizia lìindicizzazione recorsiva. Di default è la tua home.</translation>
    </message>
    <message>
        <source>Skipped paths</source>
        <translation>Indirizzi saltati</translation>
    </message>
    <message>
        <source>These are names of directories which indexing will not enter.&lt;br&gt; May contain wildcards. Must match the paths seen by the indexer (ie: if topdirs includes &apos;/home/me&apos; and &apos;/home&apos; is actually a link to &apos;/usr/home&apos;, a correct skippedPath entry would be &apos;/home/me/tmp*&apos;, not &apos;/usr/home/me/tmp*&apos;)</source>
        <translation>Questi sono i nomi delle cartelle in cui l&apos;indicizzazione non entra&lt;br&gt;Possono contenere caratteri speciali. Devono corrispondere agli indirizzi visti dal motore di indicizzazione (ad esempio, se la cartella superiore include &apos;/home/io&apos; e &apos;/home&apos; è in realtà un link a &apos;/usr/home&apos;, l&apos;indirizzo corretto che si vuole sltare dovrebbe essere &apos;/home/me/tmp*&apos; e non ì/home/usr/tmp*&apos;)</translation>
    </message>
    <message>
        <source>Stemming languages</source>
        <translation>Lingue per la radice </translation>
    </message>
    <message>
        <source>The languages for which stemming expansion&lt;br&gt;dictionaries will be built.</source>
        <translation>Lingue per le quali verrà costruito&lt;br&gt;il dizionario delle espansioni radicali.</translation>
    </message>
    <message>
        <source>Log file name</source>
        <translation>Nome del file di log</translation>
    </message>
    <message>
        <source>The file where the messages will be written.&lt;br&gt;Use &apos;stderr&apos; for terminal output</source>
        <translation>Il file dove verranno scritti i messaggi.&lt;br&gt;Usa &apos;stderr&apos; per il terminale</translation>
    </message>
    <message>
        <source>Log verbosity level</source>
        <translation>Livello di verbosità del log</translation>
    </message>
    <message>
        <source>This value adjusts the amount of messages,&lt;br&gt;from only errors to a lot of debugging data.</source>
        <translation>Questo valore regola il numero dei messaggi,&gt;br&gt;dai soli errori a mole indicazioni per il debug.</translation>
    </message>
    <message>
        <source>Index flush megabytes interval</source>
        <translation>Intervallo in megabite per il salvataggio intermedio dell&apos;indice</translation>
    </message>
    <message>
        <source>This value adjust the amount of data which is indexed between flushes to disk.&lt;br&gt;This helps control the indexer memory usage. Default 10MB </source>
        <translation>Questo valore regola il volume di dati da indicizzare tra un salvataggio e l&apos;altro.&lt;br&gt;Aiuta a controllare l&apos;uso della memoria.  Di default è post uguale a 10Mb</translation>
    </message>
    <message>
        <source>Max disk occupation (%)</source>
        <translation>Massima occupazione del disco fisso (%)</translation>
    </message>
    <message>
        <source>This is the percentage of disk occupation where indexing will fail and stop (to avoid filling up your disk).&lt;br&gt;0 means no limit (this is the default).</source>
        <translation>Questa è la percentuale fi occupazione del disco fisso oltre la quale l&apos;indicizzazione si ferma con un errore (per evitare di riempire il disco).&lt;br&gt;0 significa nessun limite (questo è il valore di default).</translation>
    </message>
    <message>
        <source>No aspell usage</source>
        <translation>Non usare aspell</translation>
    </message>
    <message>
        <source>Aspell language</source>
        <translation>Lingua di aspell</translation>
    </message>
    <message>
        <source>The language for the aspell dictionary. This should look like &apos;en&apos; or &apos;fr&apos; ...&lt;br&gt;If this value is not set, the NLS environment will be used to compute it, which usually works.To get an idea of what is installed on your system, type &apos;aspell config&apos; and look for .dat files inside the &apos;data-dir&apos; directory. </source>
        <translation>Lingua per il dizionario aspell. Dovrebbe essere simile a &apos;en&apos; o &apos;it&apos; ...&lt;br&gt;Se questo valore non è impostato verrà usato l&apos;ambiente NLS per calcolarlo, cosa che generalmente funziona. Per avere un&apos;idea di cosa sia installato sul tuo sistema, dai il comando &apos;aspell config&apos; e guarda il nome dei files .dat nella cartella &apos;data-dir&apos;.</translation>
    </message>
    <message>
        <source>Database directory name</source>
        <translation>Nome della cartella del database</translation>
    </message>
    <message>
        <source>The name for a directory where to store the index&lt;br&gt;A non-absolute path is taken relative to the  configuration directory. The default is &apos;xapiandb&apos;.</source>
        <translation>Nome della cartella in cui salvare l&apos;indice&lt;br&gt;Un indirizzo non assoluto viene interpretato come relativo alla cartella di congigurazione. Di default è &apos;xapiandb&apos;.</translation>
    </message>
    <message>
        <source>Use system&apos;s &apos;file&apos; command</source>
        <translation>Usa il comando di sistema &apos;file&apos;</translation>
    </message>
    <message>
        <source>Use the system&apos;s &apos;file&apos; command if internal&lt;br&gt;mime type identification fails.</source>
        <translation>Usa il comando di sistema &apos;file&apos; se fallisce&lt;br&gt;l&apos;identificazione interna del tipo mime.</translation>
    </message>
    <message>
        <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful if aspell is absent or does not work. </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>uiPrefsDialogBase</name>
    <message>
        <source>User preferences</source>
        <translation>Preferenze utente</translation>
    </message>
    <message>
        <source>User interface</source>
        <translation>Interfaccia utente</translation>
    </message>
    <message>
        <source>Number of entries in a result page</source>
        <translation>Numero di risultati per pagina</translation>
    </message>
    <message>
        <source>If checked, results with the same content under different names will only be shown once.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide duplicate results.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Highlight color for query terms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Result list font</source>
        <translation>Fonts per la lista dei risultati</translation>
    </message>
    <message>
        <source>Opens a dialog to select the result list font</source>
        <translation>Apre una finestra di dialogo per selezionare i fonts della lista dei risultati</translation>
    </message>
    <message>
        <source>Helvetica-10</source>
        <translation>Helvetica-10</translation>
    </message>
    <message>
        <source>Resets the result list font to the system default</source>
        <translation>Ripristina i font della lista dei risultati</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Ripristina</translation>
    </message>
    <message>
        <source>Defines the format for each result list paragraph. Use qt html format and printf-like replacements:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %I Icon image name&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</source>
        <translation type="obsolete">Definisce il formato per ogni paragrafo dell&apos;elenco dei risultati. Usare il formato qt html e le sostituzioni tipo printf:&lt;br&gt;%A Riassunto&lt;br&gt; %D Data&lt;br&gt; %I Icona&lt;br&gt; %K Parole chiave (se esistono)&lt;br&gt; %L Link per anteprima e modifica&lt;br&gt; %M Tipo MIME&lt;br&gt; %N Numero del risultato&lt;br&gt; %R Percentuale di rilevanza&lt;br&gt; %S Informazioni sulla dimensione&lt;br&gt; %T Titolo&lt;br&gt; %U Url&lt;br&gt;</translation>
    </message>
    <message>
        <source>Result paragraph&lt;br&gt;format string</source>
        <translation type="obsolete">Stringa di formattazione&lt;br&gt;dei risultati</translation>
    </message>
    <message>
        <source>Texts over this size will not be highlighted in preview (too slow).</source>
        <translation>Testi di lunghezza superiore a questa non vengono evidenziati nella preview (troppo lento).</translation>
    </message>
    <message>
        <source>Maximum text size highlighted for preview (megabytes)</source>
        <translation>Dimensione massima del testo da evidenziare nell&apos;anteprima (megabytes)</translation>
    </message>
    <message>
        <source>Use desktop preferences to choose document editor.</source>
        <translation>Usa le preferenze del desktop per scegliere l&apos;editor dei documenti.</translation>
    </message>
    <message>
        <source>Choose editor applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display category filter as toolbar instead of button panel (needs restart).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-start simple search on whitespace entry.</source>
        <translation>Inizia automaticamente una ricerca semplice digitando uno spazio.</translation>
    </message>
    <message>
        <source>Start with advanced search dialog open.</source>
        <translation>Inizia aprendo la finestra di ricerca avanzata.</translation>
    </message>
    <message>
        <source>Start with sort dialog open.</source>
        <translation type="obsolete">Inizia con la finestra di ordinamento aperta.</translation>
    </message>
    <message>
        <source>Remember sort activation state.</source>
        <translation>Ricorda lo stato dell&apos;impostazione di ordinamento.</translation>
    </message>
    <message>
        <source>Prefer Html to plain text for preview.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search parameters</source>
        <translation>Parametri per la ricerca</translation>
    </message>
    <message>
        <source>Stemming language</source>
        <translation>Linguaggio per l&apos;espansione</translation>
    </message>
    <message>
        <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)]. 
This should give higher precedence to the results where the search terms appear exactly as entered.</source>
        <translation>Una ricerca per [vino rosso] (2 parole) sara&apos; completata come [vino O rosso O (vino FRASE 2 rosso)]. 
Questo dovrebbe dare la precedenza ai risultati che contengono i termini esattamente come sono stati scritti.</translation>
    </message>
    <message>
        <source>Automatically add phrase to simple searches</source>
        <translation>Aggiungi automaticamente frase alle ricerche semplici</translation>
    </message>
    <message>
        <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
May be slow for big documents.</source>
        <translation>Devo cercare di costruire i riassunti per le voci nell&apos;elenco dei risultati usando il contesto dei termini di ricerca?
Puo&apos; essere lento per grossi documenti..</translation>
    </message>
    <message>
        <source>Dynamically build abstracts</source>
        <translation>Costruisci dinamicamente i riassunti</translation>
    </message>
    <message>
        <source>Do we synthetize an abstract even if the document seemed to have one?</source>
        <translation>Devo sintetizzare un riassunto anche se il documento sembra ne abbia uno?</translation>
    </message>
    <message>
        <source>Replace abstracts from documents</source>
        <translation>Sostituisci i riassunti dei documenti</translation>
    </message>
    <message>
        <source>Synthetic abstract size (characters)</source>
        <translation>Numero caratteri per il riassunto</translation>
    </message>
    <message>
        <source>Synthetic abstract context words</source>
        <translation>Numero di parole di contesto per il riassunto</translation>
    </message>
    <message>
        <source>The words in the list will be automatically turned to ext:xxx clauses in the query language entry.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Query language magic file name suffixes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>External Indexes</source>
        <translation>Indici esterni</translation>
    </message>
    <message>
        <source>Toggle selected</source>
        <translation>Commuta selezionati</translation>
    </message>
    <message>
        <source>Activate All</source>
        <translation>Seleziona tutti</translation>
    </message>
    <message>
        <source>Deactivate All</source>
        <translation>Deseleziona tutti</translation>
    </message>
    <message>
        <source>Remove from list. This has no effect on the disk index.</source>
        <translation>Rimuovi dalla lista. Non ha effetto sull&apos;indice del disco.</translation>
    </message>
    <message>
        <source>Remove selected</source>
        <translation>Rimuovi selezionati</translation>
    </message>
    <message>
        <source>Click to add another index directory to the list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add index</source>
        <translation>Aggiungi indice</translation>
    </message>
    <message>
        <source>Apply changes</source>
        <translation>Applica modifiche</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Discard changes</source>
        <translation>Annulla modifiche</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <source>Abstract snippet separator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style sheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opens a dialog to select the style sheet file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resets the style sheet to default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines in PRE text are not folded. Using BR loses some indentation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use &lt;PRE&gt; tags instead of &lt;BR&gt;to display plain text as html in preview.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Result List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit result paragraph format string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit result page html header insert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date format (strftime(3))</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frequency percentage threshold over which we do not use terms inside autophrase. 
Frequent terms are a major performance issue with phrases. 
Skipped terms augment the phrase slack, and reduce the autophrase efficiency.
The default value is 2 (percent). </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autophrase term frequency threshold percentage</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
